package envoy.client.ui;

/**
 * Contains information about different scenes and their FXML resource files.
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Client v0.1-beta
 */
public enum SceneInfo {

	/**
	 * The main scene in which the chat screen is displayed.
	 *
	 * @since Envoy Client v0.1-beta
	 */
	CHAT_SCENE("/fxml/ChatScene.fxml"),

	/**
	 * The scene in which the settings screen is displayed.
	 *
	 * @since Envoy Client v0.1-beta
	 */
	SETTINGS_SCENE("/fxml/SettingsScene.fxml"),

	/**
	 * The scene in which the login screen is displayed.
	 *
	 * @since Envoy Client v0.1-beta
	 */
	LOGIN_SCENE("/fxml/LoginScene.fxml", false);

	/**
	 * The path to the FXML resource.
	 */
	public final String path;

	/**
	 * Whether the scene should be resizable.
	 */
	public final boolean resizable;

	SceneInfo(String path) {
		this(path, true);
	}

	SceneInfo(String path, boolean resizable) {
		this.path = path;
		this.resizable	= resizable;
	}
}